# YTube

***
This is a simple YouTube video downloader implemented in Python.

## INSTALLATION
---
```Python
pip install YTube
```
or
```Python
pip3 install YTube
```

## IMPORT
---
```Python
   import YTube
```

## DOWNLOADING VIDEOS
---
1. ```Python
   YTube.download("Put link here")
    ```
    Download video in the basic resolution.

2. ```Python
   YTube.fastDownload("Put link here")
    ```
    Fast download

3. ```Python
    YTube.download_144("Put link here")
    ```
    Download video in 144p

4. ```Python
    YTube.download_360("Put link here")
    ```
    Download video in 360p

5. ```Python
    YTube.download_480("Put link here")
    ```
    Download video in 480p

6. ```Python
    YTube.download_720("Put link here")
    ```
    Download video in 720p

7. ```Python
    YTube.download_1080("Put link here")
    ```
    Download video in 1080p






